@@ -4,7 +4,7 @@ import logging
 
 import pandas as pd
 from pandas._typing import NDFrameT
-from pandas.core.indexing import _LocIndexer
+from pandas.io.parsers.readers import TextFileReader
 from pangres import upsert
 import numpy as np
 import typing
@@ -29,7 +29,7 @@ class DataFrameState:
 @_decorate_all_methods(_return_custom_df_on_call)
 class DataFrame(pd.DataFrame):
 
-    def __init__(self, from_df: pd.DataFrame = None, from_csv=None, from_sql_query=None, from_iterator=None):
+    def __init__(self, from_df: pd.DataFrame = None, from_csv=None, from_sql_query=None, from_iterator=None, chunksize=None):
         super().__init__()
         self._dataframe_state = DataFrameState()
         self.__is_valide = False
@@ -40,7 +40,7 @@ class DataFrame(pd.DataFrame):
             return self.__is_valide
         try:
             for data_type in self._dataframe_state.data_types:
-                if data_type.col_obj_series.dtype != self[data_type.name].dtype:
+                if data_type.base_type not in self[data_type.name].dtype.name:
                     raise ValidationError(
                         f"The column {data_type.name} is not of type {data_type.col_obj_series.dtype}")
             self.__is_valide = True
@@ -55,7 +55,7 @@ class DataFrame(pd.DataFrame):
         for data_type in self._dataframe_state.data_types:
             if data_type.str_type == 'datetime64[ns]':
                 self[data_type.name] = pd.to_datetime(self[data_type.name],
-                                                      format=data_type.col_obj_series.kwargs['format'])
+                                                      format=data_type.col_obj_series.kwargs.get('format'))
             else:
                 self[data_type.name] = self[data_type.name].astype(data_type.str_type)
         self.is_valid()
@@ -80,8 +80,8 @@ class DataFrame(pd.DataFrame):
             if kwargs.get('if_exists') is None:
                 kwargs['if_exists'] = 'append'
             elif kwargs.get('if_exists') == 'replace':
-                raise ValueError(f'got an unexpected value "if_exists=replace". Please use a normal pandas dataframe '
-                                 f'to access this functionality')
+                raise TypeError(f'got an unexpected value "if_exists=replace". Please use a normal pandas dataframe '
+                                f'to access this functionality')
             if kwargs.get('index') is None:
                 kwargs['index'] = False
             elif kwargs.get('index') is True:
@@ -153,6 +153,7 @@ class DataFrame(pd.DataFrame):
 @dataclass
 class DataTypes:
     name: str
+    base_type: str
     str_type: str
     np_type: np.generic
     col_obj_series: pd.Series
@@ -172,6 +173,7 @@ class Data:
         self.data_types: List[DataTypes] = [
             DataTypes(
                 name=attr_key,
+                base_type=attr_val.base_type,
                 str_type=attr_val.str_type,
                 np_type=attr_val.np_type,
                 col_obj_series=getattr(self.decorated_class, attr_key),
@@ -241,17 +243,25 @@ class Data:
             df = kwargs.get('from_df')
         else:
             df = func(**kwargs)
+        if isinstance(df, TextFileReader):
+            return self.df_generator(df, bool_validator)
+        self.build_custom_df(df, bool_validator)
+        return self.df
+
+    def df_generator(self, df, bool_validator):
+        for chunk in df:
+            self.init_new_custom_df()
+            self.build_custom_df(chunk, bool_validator)
+            yield self.df
+
+    def build_custom_df(self, df, bool_validator):
+        # Convert bool values
         for col_name, bool_val_dict in bool_validator.items():
             df[col_name] = df[col_name].map(bool_val_dict)
 
         for data_type in self.data_types:
             self.df[data_type.name] = df[data_type.target_name]
 
-        return self.df
-
-    def validate(self):
-        self.init_new_custom_df()
-
     def init_new_custom_df(self):
         self.df = DataFrame()
         self.df.dataframe_state.decorated_class = self.decorated_class
